import React, { useMemo, useRef, useState } from 'react'
import { Button, notification, Spin, Badge, Select } from 'antd'
import { router } from 'umi'
import moment from 'moment'
import QueryTable from '@/components/QueryTable'
import { fetch, apis } from '@/utils/request';
import { useEffect } from 'react'

const searchFields = [
  {
    name: 'name',
    label: '姓名',
    placeholder: '请输入客户姓名',
  },
  {
    name: 'phone',
    label: '手机号',
    placeholder: '请输入客户手机号',
  },
]

export default (props) => {
  const { history } = props
  const { recommendPerson } = history.location.query

  const ref = useRef()
  const [notQuery, setNotQuery] = useState(true);

  const tableColumns = [
    {
      title: '姓名',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: '手机号',
      dataIndex: 'phone',
      key: 'phone',
    },
    {
      title: '归属楼盘',
      dataIndex: 'buildingName',
      key: 'buildingName',
    },
    {
      title: '客户状态',
      dataIndex: 'status',
      key: 'status',
      render: (_, row) => {
        if (!row.status || row.status <= 1) {
          return '待审核';
        } else if (row.status === 3) {
          return '驳回';
        } else {
          if (!row.commission_date) {
            return '结佣';
          }
          if (!row.signed_date) {
            return '签约';
          }
          if (!row.preparatory_date) {
            return '认筹';
          }
          if (!row.visit_date) {
            return '到访';
          }
        }

        return '未知';
      }
    },
    {
      title: '佣金总数',
      dataIndex: 'totalCommission',
      key: 'totalCommission',
      align: 'right',
      width: 120,
      render: t => t && t > 0 ? `￥${Number(t / 100).toFixed(2)}元` : '-'
    },
    {
      title: '已结佣金',
      dataIndex: 'settledCommission',
      key: 'settledCommission',
      align: 'right',
      width: 120,
      render: t => t && t > 0 ? `￥${Number(t / 100).toFixed(2)}元` : '-'
    },
    {
      title: '待结佣金',
      dataIndex: 'unsettledCommission',
      key: 'unsettledCommission',
      align: 'right',
      width: 120,
      render: t => t && t > 0 ? `￥${Number(t / 100).toFixed(2)}元` : '-'
    },
    {
      title: '时间',
      dataIndex: 'createDate',
      key: 'createDate',
      align: 'center',
      render: (t) => moment(t).format('YYYY-MM-DD HH:mm')
    },
  ]

  useEffect(() => {
    setNotQuery(!recommendPerson);

    if (!recommendPerson) {
      notification.warning({ message: "请设置经纪人" })
    }
  }, [recommendPerson])

  return (
    <QueryTable
      ref={ref}
      rowKey="channelCustomerId"
      api={apis.broker.getCustomerList}
      searchFields={searchFields}
      columns={tableColumns}
      params={{ recommendPerson }}
    />
  )
}
